@@ -1,13 +1,18 @@
 import os
 
-from matminer.datasets.utils import _load_dataset_dict, _get_data_home, \
-    _validate_dataset
+from matminer.datasets.utils import (
+    _load_dataset_dict,
+    _get_data_home,
+    _validate_dataset,
+)
 from matminer.utils.io import load_dataframe_from_json
 
-__author__ = "Kyle Bystrom <kylebystrom@berkeley.edu>, " \
-             "Anubhav Jain <ajain@lbl.gov>, " \
-             "Daniel Dopp <dbdopp@lbl.gov>, " \
-             "Alex Dunn <ardunn@lbl.gov"
+__author__ = (
+    "Kyle Bystrom <kylebystrom@berkeley.edu>, "
+    "Anubhav Jain <ajain@lbl.gov>, "
+    "Daniel Dopp <dbdopp@lbl.gov>, "
+    "Alex Dunn <ardunn@lbl.gov"
+)
 
 _dataset_dict = None
 
@@ -38,35 +43,37 @@ def load_dataset(name, data_home=None, download_if_missing=True):
         _dataset_dict = _load_dataset_dict()
 
     if name not in _dataset_dict:
-        error_string = "Unrecognized dataset name: {}. \n" \
-                       "Use matminer.datasets.get_available_datasets() " \
-                       "to see a list of currently available " \
-                       "datasets".format(name)
+        error_string = (
+            "Unrecognized dataset name: {}. \n"
+            "Use matminer.datasets.get_available_datasets() "
+            "to see a list of currently available "
+            "datasets".format(name)
+        )
 
         # Very simple attempt to match unrecognized keyword to existing
         # dataset names in an attempt to give the user immediate feedback
-        possible_matches = [
-            x for x in _dataset_dict.keys() if name.lower() in x.lower()
-        ]
+        possible_matches = [x for x in _dataset_dict.keys() if name.lower() in x.lower()]
 
         if possible_matches:
-            error_string += "\nCould you have been looking for these similar " \
-                            "matches?:\n{}".format(possible_matches)
+            error_string += "\nCould you have been looking for these similar " "matches?:\n{}".format(possible_matches)
 
         raise ValueError(error_string)
 
     dataset_metadata = _dataset_dict[name]
-    data_path = os.path.join(_get_data_home(data_home),
-                             name + "." + dataset_metadata['file_type'])
-    _validate_dataset(data_path, dataset_metadata['url'],
-                      dataset_metadata['hash'], download_if_missing)
+    data_path = os.path.join(_get_data_home(data_home), name + "." + dataset_metadata["file_type"])
+    _validate_dataset(
+        data_path,
+        dataset_metadata["url"],
+        dataset_metadata["hash"],
+        download_if_missing,
+    )
 
-    df = load_dataframe_from_json(data_path)
+    df = load_dataframe_from_json(data_path, pbar=True)
 
     return df
 
 
-def get_available_datasets(print_format="medium", sort_method='alphabetical'):
+def get_available_datasets(print_format="medium", sort_method="alphabetical"):
     """
     Function for retrieving the datasets available within matminer.
 
@@ -91,13 +98,14 @@ def get_available_datasets(print_format="medium", sort_method='alphabetical'):
         _dataset_dict = _load_dataset_dict()
 
     if sort_method not in {"alphabetical", "num_entries"}:
-        raise ValueError("Error, unsupported sorting metric {}"
-                         " see docs for options".format(sort_method))
+        raise ValueError("Error, unsupported sorting metric {}" " see docs for options".format(sort_method))
 
-    if sort_method == 'num_entries':
-        dataset_names = sorted(_dataset_dict.keys(),
-                               key=lambda x: _dataset_dict[x]["num_entries"],
-                               reverse=True)
+    if sort_method == "num_entries":
+        dataset_names = sorted(
+            _dataset_dict.keys(),
+            key=lambda x: _dataset_dict[x]["num_entries"],
+            reverse=True,
+        )
     else:
         dataset_names = sorted(_dataset_dict.keys())
 
@@ -110,8 +118,7 @@ def get_available_datasets(print_format="medium", sort_method='alphabetical'):
         elif print_format == "medium":
             for dataset_name in dataset_names:
                 dataset_description = get_dataset_description(dataset_name)
-                dataset_string += f"{dataset_name}: " \
-                                  f"{dataset_description}\n\n"
+                dataset_string += f"{dataset_name}: " f"{dataset_description}\n\n"
         elif print_format == "long":
             for dataset_name in dataset_names:
                 dataset_string += f"{get_all_dataset_info(dataset_name)}"
@@ -149,7 +156,7 @@ def get_dataset_citations(dataset_name):
 
     Returns: (list)
     """
-    return get_dataset_attribute(dataset_name, 'bibtex_refs')
+    return get_dataset_attribute(dataset_name, "bibtex_refs")
 
 
 def get_dataset_reference(dataset_name):
@@ -161,7 +168,7 @@ def get_dataset_reference(dataset_name):
 
     Returns: (str)
     """
-    return get_dataset_attribute(dataset_name, 'reference')
+    return get_dataset_attribute(dataset_name, "reference")
 
 
 def get_dataset_description(dataset_name):
@@ -173,7 +180,7 @@ def get_dataset_description(dataset_name):
 
     Returns: (str)
     """
-    return get_dataset_attribute(dataset_name, 'description')
+    return get_dataset_attribute(dataset_name, "description")
 
 
 def get_dataset_num_entries(dataset_name):
@@ -185,7 +192,7 @@ def get_dataset_num_entries(dataset_name):
 
     Returns: (int)
     """
-    return get_dataset_attribute(dataset_name, 'num_entries')
+    return get_dataset_attribute(dataset_name, "num_entries")
 
 
 def get_dataset_columns(dataset_name):
@@ -197,7 +204,7 @@ def get_dataset_columns(dataset_name):
 
     Returns: (list)
     """
-    return list(get_dataset_attribute(dataset_name, 'columns').keys())
+    return list(get_dataset_attribute(dataset_name, "columns").keys())
 
 
 def get_dataset_column_description(dataset_name, dataset_column):
@@ -210,7 +217,7 @@ def get_dataset_column_description(dataset_name, dataset_column):
 
     Returns: (str)
     """
-    return get_dataset_attribute(dataset_name, 'columns')[dataset_column]
+    return get_dataset_attribute(dataset_name, "columns")[dataset_column]
 
 
 def get_all_dataset_info(dataset_name):
@@ -233,8 +240,7 @@ def get_all_dataset_info(dataset_name):
     columns = get_dataset_columns(dataset_name)
     column_descriptions = []
     for c in columns:
-        column_descriptions.append(
-            get_dataset_column_description(dataset_name, c))
+        column_descriptions.append(get_dataset_column_description(dataset_name, c))
     reference = get_dataset_reference(dataset_name)
     citations = get_dataset_citations(dataset_name)
     num_entries = get_dataset_num_entries(dataset_name)
@@ -242,16 +248,17 @@ def get_all_dataset_info(dataset_name):
     url = get_dataset_attribute(dataset_name, "url")
     h = get_dataset_attribute(dataset_name, "hash")
 
-    output_str = f"Dataset: {dataset_name}\nDescription: {description}" \
-                 f"\nColumns:\n"
+    output_str = f"Dataset: {dataset_name}\nDescription: {description}" f"\nColumns:\n"
     for i, c in enumerate(columns):
         cd = column_descriptions[i]
         output_str += f"\t{c}: {cd}\n"
-    output_str += f"Num Entries: {num_entries}\n" \
-                  f"Reference: {reference}\n" \
-                  f"Bibtex citations: {citations}\n" \
-                  f"File type: {file_type}\n" \
-                  f"Figshare URL: {url}\n" \
-                  f"SHA256 Hash Digest: {h}\n\n"
+    output_str += (
+        f"Num Entries: {num_entries}\n"
+        f"Reference: {reference}\n"
+        f"Bibtex citations: {citations}\n"
+        f"File type: {file_type}\n"
+        f"Figshare URL: {url}\n"
+        f"SHA256 Hash Digest: {h}\n\n"
+    )
 
     return output_str
