@@ -1,10 +1,18 @@
 import unittest
 
 from matminer.datasets.tests.base import DatasetTest
-from matminer.datasets.dataset_retrieval import load_dataset, \
-    get_available_datasets, get_dataset_attribute, get_dataset_description, \
-    get_dataset_num_entries, get_dataset_columns, get_dataset_reference, \
-    get_dataset_column_description, get_dataset_citations, get_all_dataset_info
+from matminer.datasets.dataset_retrieval import (
+    load_dataset,
+    get_available_datasets,
+    get_dataset_attribute,
+    get_dataset_description,
+    get_dataset_num_entries,
+    get_dataset_columns,
+    get_dataset_reference,
+    get_dataset_column_description,
+    get_dataset_citations,
+    get_all_dataset_info,
+)
 
 
 class DataRetrievalTest(DatasetTest):
@@ -26,21 +34,23 @@ class DataRetrievalTest(DatasetTest):
     def test_print_available_datasets(self):
         # Go over all parameter combinations,
         # for each check that returned dataset is correct
-        for sort_method in ['alphabetical', 'num_entries']:
+        for sort_method in ["alphabetical", "num_entries"]:
             datasets = get_available_datasets(sort_method=sort_method)
-            if sort_method == 'alphabetical':
+            if sort_method == "alphabetical":
                 self.assertEqual(datasets, sorted(self.dataset_names))
             else:
                 self.assertEqual(
                     datasets,
-                    sorted(self.dataset_names,
-                           key=lambda x: self.dataset_dict[x]['num_entries'],
-                           reverse=True)
+                    sorted(
+                        self.dataset_names,
+                        key=lambda x: self.dataset_dict[x]["num_entries"],
+                        reverse=True,
+                    ),
                 )
 
     def test_get_dataset_attribute(self):
         dataset_name = sorted(self.dataset_dict.keys())[0]
-        file_type = get_dataset_attribute(dataset_name, 'file_type')
+        file_type = get_dataset_attribute(dataset_name, "file_type")
         self.assertTrue(isinstance(file_type, str))
 
     def test_get_dataset_description(self):
@@ -65,8 +75,7 @@ class DataRetrievalTest(DatasetTest):
 
     def test_get_dataset_column_descriptions(self):
         dataset_name = sorted(self.dataset_dict.keys())[0]
-        dataset_column = sorted(
-            self.dataset_dict[dataset_name]["columns"].keys())[0]
+        dataset_column = sorted(self.dataset_dict[dataset_name]["columns"].keys())[0]
         attrib = get_dataset_column_description(dataset_name, dataset_column)
         self.assertTrue(isinstance(attrib, str))
 
