@@ -14,6 +14,7 @@ from monty.json import MontyDecoder
 from pymatgen.ext.matproj import MPRester
 from pymatgen.core.structure import IStructure
 from pymatgen.core.composition import Composition
+from pymatgen.io.ase import AseAtomsAdaptor
 
 from matminer.featurizers.base import BaseFeaturizer
 
@@ -78,8 +79,8 @@ class ConversionFeaturizer(BaseFeaturizer):
         # now the col_id is known, we check if we need to update target_col_id
         # for multiindexes it is the last index that is updated
         target = self._target_col_id
-        if isinstance(target, str) and target[0] == '_':
-            if 'multiindex' in kwargs and kwargs['multiindex']:
+        if isinstance(target, str) and target[0] == "_":
+            if "multiindex" in kwargs and kwargs["multiindex"]:
                 self._target_col_id = "{}_{}".format(col_id[-1], target[1:])
             else:
                 self._target_col_id = "{}_{}".format(col_id, target[1:])
@@ -125,8 +126,7 @@ class StrToComposition(ConversionFeaturizer):
             exists.
     """
 
-    def __init__(self, reduce=False, target_col_id='composition',
-                 overwrite_data=False):
+    def __init__(self, reduce=False, target_col_id="composition", overwrite_data=False):
         super().__init__(target_col_id, overwrite_data)
         self.reduce = reduce
         self._chunksize = 30
@@ -154,7 +154,8 @@ class StrToComposition(ConversionFeaturizer):
             "properties of inorganic materials}, volume={2}, "
             "DOI={10.1038/npjcompumats.2017.28}, number={1}, journal={npj "
             "Computational Materials}, author={Ward, Logan and Agrawal, Ankit "
-            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"]
+            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"
+        ]
 
     def implementors(self):
         return ["Anubhav Jain", "Alex Ganose"]
@@ -183,8 +184,7 @@ class StructureToComposition(ConversionFeaturizer):
             exists.
     """
 
-    def __init__(self, reduce=False, target_col_id='composition',
-                 overwrite_data=False):
+    def __init__(self, reduce=False, target_col_id="composition", overwrite_data=False):
         super().__init__(target_col_id, overwrite_data)
         self.reduce = reduce
         self._overwrite = overwrite_data
@@ -212,7 +212,8 @@ class StructureToComposition(ConversionFeaturizer):
             "properties of inorganic materials}, volume={2}, "
             "DOI={10.1038/npjcompumats.2017.28}, number={1}, journal={npj "
             "Computational Materials}, author={Ward, Logan and Agrawal, Ankit "
-            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"]
+            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"
+        ]
 
     def implementors(self):
         return ["Anubhav Jain", "Alex Ganose"]
@@ -242,7 +243,7 @@ class StructureToIStructure(ConversionFeaturizer):
             exists.
     """
 
-    def __init__(self, target_col_id='istructure', overwrite_data=False):
+    def __init__(self, target_col_id="istructure", overwrite_data=False):
         super().__init__(target_col_id, overwrite_data)
         self._overwrite = overwrite_data
         self._chunksize = 30
@@ -266,7 +267,8 @@ class StructureToIStructure(ConversionFeaturizer):
             "properties of inorganic materials}, volume={2}, "
             "DOI={10.1038/npjcompumats.2017.28}, number={1}, journal={npj "
             "Computational Materials}, author={Ward, Logan and Agrawal, Ankit "
-            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"]
+            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"
+        ]
 
     def implementors(self):
         return ["Logan Ward", "Alex Ganose"]
@@ -292,7 +294,7 @@ class DictToObject(ConversionFeaturizer):
             exists.
     """
 
-    def __init__(self, target_col_id='_object', overwrite_data=False):
+    def __init__(self, target_col_id="_object", overwrite_data=False):
         super().__init__(target_col_id, overwrite_data)
         self._chunksize = 30
 
@@ -316,7 +318,8 @@ class DictToObject(ConversionFeaturizer):
             "properties of inorganic materials}, volume={2}, "
             "DOI={10.1038/npjcompumats.2017.28}, number={1}, journal={npj "
             "Computational Materials}, author={Ward, Logan and Agrawal, Ankit "
-            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"]
+            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"
+        ]
 
     def implementors(self):
         return ["Anubhav Jain", "Alex Ganose"]
@@ -342,7 +345,7 @@ class JsonToObject(ConversionFeaturizer):
             exists.
     """
 
-    def __init__(self, target_col_id='_object', overwrite_data=False):
+    def __init__(self, target_col_id="_object", overwrite_data=False):
         super().__init__(target_col_id, overwrite_data)
         self._chunksize = 30
 
@@ -365,7 +368,8 @@ class JsonToObject(ConversionFeaturizer):
             "properties of inorganic materials}, volume={2}, "
             "DOI={10.1038/npjcompumats.2017.28}, number={1}, journal={npj "
             "Computational Materials}, author={Ward, Logan and Agrawal, Ankit "
-            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"]
+            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"
+        ]
 
     def implementors(self):
         return ["Anubhav Jain", "Alex Ganose"]
@@ -399,8 +403,7 @@ class StructureToOxidStructure(ConversionFeaturizer):
             `pymatgen.io.structure.Structure.add_oxidation_state_by_guess()`.
     """
 
-    def __init__(self, target_col_id='structure_oxid', overwrite_data=False,
-                 return_original_on_error=False, **kwargs):
+    def __init__(self, target_col_id="structure_oxid", overwrite_data=False, return_original_on_error=False, **kwargs):
         super().__init__(target_col_id, overwrite_data)
         self.oxi_guess_params = kwargs
         self.return_original_on_error = return_original_on_error
@@ -415,8 +418,7 @@ class StructureToOxidStructure(ConversionFeaturizer):
             (`pymatgen.core.structure.Structure`): A Structure object decorated
                 with oxidation states.
         """
-        els_have_oxi_states = [hasattr(s, "oxi_state") for s in
-                               structure.composition.elements]
+        els_have_oxi_states = [hasattr(s, "oxi_state") for s in structure.composition.elements]
         if all(els_have_oxi_states):
             return [structure]
 
@@ -435,7 +437,8 @@ class StructureToOxidStructure(ConversionFeaturizer):
             "properties of inorganic materials}, volume={2}, "
             "DOI={10.1038/npjcompumats.2017.28}, number={1}, journal={npj "
             "Computational Materials}, author={Ward, Logan and Agrawal, Ankit "
-            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"]
+            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"
+        ]
 
     def implementors(self):
         return ["Anubhav Jain", "Alex Ganose"]
@@ -473,9 +476,14 @@ class CompositionToOxidComposition(ConversionFeaturizer):
 
     """
 
-    def __init__(self, target_col_id='composition_oxid', overwrite_data=False,
-                 coerce_mixed=True, return_original_on_error=False,
-                 **kwargs):
+    def __init__(
+        self,
+        target_col_id="composition_oxid",
+        overwrite_data=False,
+        coerce_mixed=True,
+        return_original_on_error=False,
+        **kwargs,
+    ):
         super().__init__(target_col_id, overwrite_data)
         self.oxi_guess_params = kwargs
         self.coerce_mixed = coerce_mixed
@@ -500,13 +508,14 @@ class CompositionToOxidComposition(ConversionFeaturizer):
             if self.coerce_mixed:
                 comp = comp.element_composition
             else:
-                raise ValueError("Composition {} has a mix of species with "
-                                 "and without oxidation states. Please enable "
-                                 "coercion to all oxidation states with "
-                                 "coerce_mixed.".format(comp))
+                raise ValueError(
+                    "Composition {} has a mix of species with "
+                    "and without oxidation states. Please enable "
+                    "coercion to all oxidation states with "
+                    "coerce_mixed.".format(comp)
+                )
         try:
-            comp = comp.add_charges_from_oxi_state_guesses(
-                **self.oxi_guess_params)
+            comp = comp.add_charges_from_oxi_state_guesses(**self.oxi_guess_params)
         except ValueError as e:
             if not self.return_original_on_error:
                 raise e
@@ -519,7 +528,8 @@ class CompositionToOxidComposition(ConversionFeaturizer):
             "properties of inorganic materials}, volume={2}, "
             "DOI={10.1038/npjcompumats.2017.28}, number={1}, journal={npj "
             "Computational Materials}, author={Ward, Logan and Agrawal, Ankit "
-            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"]
+            "and Choudhary, Alok and Wolverton, Christopher}, year={2016}}"
+        ]
 
     def implementors(self):
         return ["Anubhav Jain", "Alex Ganose", "Alex Dunn"]
@@ -546,8 +556,7 @@ class CompositionToStructureFromMP(ConversionFeaturizer):
 
     """
 
-    def __init__(self, target_col_id='structure', overwrite_data=False,
-                 mapi_key=None):
+    def __init__(self, target_col_id="structure", overwrite_data=False, mapi_key=None):
         super().__init__(target_col_id, overwrite_data)
         self.mpr = MPRester(mapi_key)
         self.set_n_jobs(1)
@@ -564,12 +573,10 @@ class CompositionToStructureFromMP(ConversionFeaturizer):
 
         entries = self.mpr.get_data(comp.reduced_formula, prop="energy_per_atom")
         if len(entries) > 0:
-            most_stable_entry = \
-            sorted(entries, key=lambda e: e['energy_per_atom'])[0]
-            s = self.mpr.get_structure_by_material_id(
-                most_stable_entry["material_id"])
-            return[s]
-        
+            most_stable_entry = sorted(entries, key=lambda e: e["energy_per_atom"])[0]
+            s = self.mpr.get_structure_by_material_id(most_stable_entry["material_id"])
+            return [s]
+
         return [float("nan")]
 
     def citations(self):
@@ -594,7 +601,76 @@ class CompositionToStructureFromMP(ConversionFeaturizer):
             "flexible and efficient API for materials data based on "
             "REpresentational State Transfer (REST) principles}}, "
             "url = {http://linkinghub.elsevier.com/retrieve/pii/S0927025614007113}, "
-            "volume = {97}, year = {2015} } "]
+            "volume = {97}, year = {2015} } ",
+        ]
 
     def implementors(self):
         return ["Anubhav Jain"]
+
+
+class PymatgenFunctionApplicator(ConversionFeaturizer):
+    """
+    Featurizer to run any function using on/from pymatgen primitives.
+
+    For example, apply
+
+        lambda structure: structure.composition.anonymized_formula
+
+    To all rows in a dataframe.
+
+    And return the results in the specified column.
+
+    Args:
+        func (function): Function object or lambda to pass the pmg primitive objects to.
+        func_args (list): List of args to pass along with the pmg object to func.
+        func_kwargs (dict): Dict of kwargs to pass along with the pmg object to func,
+        target_col_id (str): Output column for the results. If not provided, the func name
+            will be used.
+        overwrite_data (bool): If True, will overwrite target_col_id even if there is
+            data currently in that column
+    """
+
+    def __init__(self, func, func_args=None, func_kwargs=None, target_col_id=None, overwrite_data=False):
+
+        if not callable(func):
+            raise TypeError(f"Function {func} is not callable!")
+
+        if not target_col_id:
+            target_col_id = func.__name__
+
+        super().__init__(target_col_id, overwrite_data)
+
+        self.func = func
+        self.func_args = func_args if func_args else []
+        self.func_kwargs = func_kwargs if func_kwargs else {}
+
+        # n_jobs must be set to 1 to avoid pickling errors
+        self.set_n_jobs(1)
+
+    def featurize(self, obj):
+        return self.func(obj, *self.func_args, **self.func_kwargs)
+
+    def implementors(self):
+        return ["Alex Dunn"]
+
+
+class ASEAtomstoStructure(ConversionFeaturizer):
+    """
+    Convert dataframes of ase structures to pymatgen structures for further use with
+    matminer.
+
+    Args:
+        target_col_id (str): Column to place PMG structures.
+        overwrite_data (bool): If True, will overwrite target_col_id even if there is
+            data currently in that column
+    """
+
+    def __init__(self, target_col_id="PMG Structure from ASE Atoms", overwrite_data=False):
+        super().__init__(target_col_id, overwrite_data)
+        self.aaa = AseAtomsAdaptor()
+
+    def featurize(self, ase_atoms):
+        return self.aaa.get_structure(ase_atoms)
+
+    def implementors(self):
+        return ["Alex Dunn"]
