@@ -1,5 +1,3 @@
-from __future__ import division
-
 import scipy
 
 """
@@ -51,8 +49,7 @@ class PropertyStats(object):
             float - Desired statistic
         """
         statistics = stat.split("::")
-        return getattr(PropertyStats, statistics[0])(data_lst, weights,
-                                                     *statistics[1:])
+        return getattr(PropertyStats, statistics[0])(data_lst, weights, *statistics[1:])
 
     @staticmethod
     def minimum(data_lst, weights=None):
@@ -88,8 +85,7 @@ class PropertyStats(object):
         Returns:
             range
         """
-        return (max(data_lst) - min(data_lst)) if not np.any(np.isnan(data_lst)) \
-            else float("nan")
+        return (max(data_lst) - min(data_lst)) if not np.any(np.isnan(data_lst)) else float("nan")
 
     @staticmethod
     def mean(data_lst, weights=None):
@@ -150,11 +146,8 @@ class PropertyStats(object):
         if weights is None:
             return np.std(data_lst)
         else:
-            beta = np.sum(weights) / (
-                        np.sum(weights) ** 2 - np.sum(np.power(weights, 2)))
-            dev = np.power(np.subtract(data_lst, PropertyStats.mean(data_lst,
-                                                                    weights=weights)),
-                           2)
+            beta = np.sum(weights) / (np.sum(weights) ** 2 - np.sum(np.power(weights, 2)))
+            dev = np.power(np.subtract(data_lst, PropertyStats.mean(data_lst, weights=weights)), 2)
             return np.sqrt(beta * np.dot(dev, weights))
 
     @staticmethod
@@ -235,8 +228,7 @@ class PropertyStats(object):
 
         # Compute the geometric std dev
         mean = PropertyStats.holder_mean(data_lst, weights, 0)
-        beta = np.sum(weights) / (
-                    np.sum(weights) ** 2 - np.sum(np.power(weights, 2)))
+        beta = np.sum(weights) / (np.sum(weights) ** 2 - np.sum(np.power(weights, 2)))
         dev = np.log(np.true_divide(data_lst, mean))
         return np.sqrt(np.exp(beta * np.dot(weights, np.power(dev, 2))))
 
@@ -299,13 +291,12 @@ class PropertyStats(object):
 
             # If power=0, return geometric mean
             elif power == 0:
-                return np.product(np.power(data_lst, np.true_divide(weights,
-                                                                    np.sum(
-                                                                        weights))))
+                return np.product(np.power(data_lst, np.true_divide(weights, np.sum(weights))))
             else:
-                return np.power(np.sum(
-                    np.multiply(weights, np.power(data_lst, power))) / alpha,
-                                1.0 / power)
+                return np.power(
+                    np.sum(np.multiply(weights, np.power(data_lst, power))) / alpha,
+                    1.0 / power,
+                )
 
     @staticmethod
     def sorted(data_lst, weights=None):
@@ -324,16 +315,14 @@ class PropertyStats(object):
             sort: wheter to sort the eigenvalues
         Returns: eigenvalues
         """
-        eigs = np.linalg.eigvalsh(data_lst) if symm else np.linalg.eigvals(
-            data_lst)
+        eigs = np.linalg.eigvalsh(data_lst) if symm else np.linalg.eigvals(data_lst)
         if sort:
             eigs.sort()
         return eigs
 
     @staticmethod
     def flatten(data_lst, weights=None):
-        """Returns a flattened copy of data_lst-as a numpy array
-        """
+        """Returns a flattened copy of data_lst-as a numpy array"""
         return np.array(data_lst).flatten()
 
     @staticmethod
